%define anolis_release 3
# NOTE: This specfile is generated from upstream at https://github.com/rhinstaller/lorax
# NOTE: Please submit changes as a pull request
%define debug_package %{nil}

Name:           lorax
Version:        40.0
Release:        %{anolis_release}%{?dist}
Summary:        Tool for creating the anaconda install images

License:        GPL-2.0-or-later
URL:            https://github.com/weldr/lorax
Source0:        https://github.com/weldr/lorax/archive/refs/tags/%{name}-%{version}-1.tar.gz
Patch001:	0001-add-loongarch64-support-for-lorax.patch

BuildRequires:  python3-devel
BuildRequires:  make
BuildRequires:  systemd-rpm-macros

Requires:       lorax-templates
%if 0%{?anolis}
Requires:       lorax-templates-anolis
%endif

Requires:       cpio
Requires:       device-mapper
Requires:       dosfstools
Requires:       e2fsprogs
Requires:       findutils
Requires:       gawk
Requires:       xorriso
Requires:       glib2
Requires:       glibc
Requires:       glibc-common
Requires:       gzip
Requires:       isomd5sum
Requires:       module-init-tools
Requires:       parted
Requires:       squashfs-tools >= 4.2
Requires:       util-linux
Requires:       xz-lzma-compat
Requires:       xz
Requires:       pigz
Requires:       pbzip2
Requires:       dracut >= 030
Requires:       kpartx
Requires:       psmisc

# Python modules
Requires:       libselinux-python3
Requires:       python3-mako
Requires:       python3-kickstart >= 3.19
Requires:       python3-dnf >= 3.2.0
Requires:       python3-librepo
Requires:       python3-pycdio

%ifarch x86_64
Requires:       hfsplus-tools
%endif

%ifarch x86_64
Requires:       syslinux >= 6.03-1
Requires:       syslinux-nonlinux >= 6.03-1
%endif

# Moved image-minimizer tool to lorax
Provides:       appliance-tools-minimizer = %{version}-%{release}
Obsoletes:      appliance-tools-minimizer < 007.7-3

%description
Lorax is a tool for creating the anaconda install images.

It also includes livemedia-creator which is used to create bootable livemedia,
including live isos and disk images. It can use libvirtd for the install, or
Anaconda's image install feature.

%package docs
Summary: Lorax html documentation
Requires: lorax = %{version}-%{release}

%description docs
Includes the full html documentation for lorax, livemedia-creator, and the pylorax library.

%package lmc-virt
Summary:  livemedia-creator libvirt dependencies
Requires: lorax = %{version}-%{release}
Requires: qemu

# Fedora edk2 builds currently only support these arches
%ifarch x86_64 aarch64
Requires: edk2-ovmf
%endif
Recommends: qemu-kvm

%description lmc-virt
Additional dependencies required by livemedia-creator when using it with qemu.

%package lmc-novirt
Summary:  livemedia-creator no-virt dependencies
Requires: lorax = %{version}-%{release}
Requires: anaconda-core
Requires: anaconda-tui
Requires: anaconda-install-env-deps
Requires: system-logos
Requires: python3-psutil

%description lmc-novirt
Additional dependencies required by livemedia-creator when using it with --no-virt
to run Anaconda.

%package templates-generic
Summary:  Generic build templates for lorax and livemedia-creator
Requires: lorax = %{version}-%{release}
Provides: lorax-templates = %{version}-%{release}

%description templates-generic
Lorax templates for creating the boot.iso and live isos are placed in
/usr/share/lorax/templates.d/99-generic

%prep
%setup -q -n %{name}-%{name}-%{version}-1
%patch001 -p1

%build

%install
make DESTDIR=$RPM_BUILD_ROOT mandir=%{_mandir} install

%files
%license COPYING
%doc AUTHORS
%doc docs/lorax.rst docs/livemedia-creator.rst docs/product-images.rst
%doc docs/*ks
%{python3_sitelib}/pylorax
%{python3_sitelib}/*.egg-info
%{_sbindir}/lorax
%{_sbindir}/mkefiboot
%{_sbindir}/livemedia-creator
%{_bindir}/mkksiso
%{_bindir}/image-minimizer
%dir %{_sysconfdir}/lorax
%config(noreplace) %{_sysconfdir}/lorax/lorax.conf
%dir %{_datadir}/lorax
%{_mandir}/man1/lorax.1*
%{_mandir}/man1/livemedia-creator.1*
%{_mandir}/man1/mkksiso.1*
%{_mandir}/man1/image-minimizer.1*
%{_tmpfilesdir}/lorax.conf

%files docs
%doc docs/html/*

%files lmc-virt

%files lmc-novirt

%files templates-generic
%dir %{_datadir}/lorax/templates.d
%{_datadir}/lorax/templates.d/*

%changelog
* Tue Dec 12 2023 Wenlong Zhang <zhangwenlong@loongson.cn> - 40.0-3
- add patch 001 for loongarch64 

* Wed Dec  6 2023 Wenlong Zhang <zhangwenlong@loongson.cn> - 40.0-2
- add loongarch64 support for lorax 

* Mon Oct 16 2023 Funda Wang <fundawang@yeah.net> - 40.0-1
- New version 40.0

* Fri Oct 28 2022 gaochang <gc-taifu@linux.alibaba.com> 37.0-6
- Reconfig the package requires

* Thu Oct 27 2022 gaochang <gc-taifu@linux.alibaba.com> 37.0-5
- Remove templates patches

* Tue May 17 2022 gcdota930915 <taifu.gc@alibaba-inc.com> 37.0-4
- Add anolis uefi parameter in grub2 cmdline

* Thu May 5 2022 gcdota930915 <taifu.gc@alibaba-inc.com> 37.0-3
- Remove nano-default-editor requirement in runtime-install.tmpl by patch
- Enable dbus_daemon service by patch
- Edit the previous changelog record

* Thu Apr 28 2022 gcdota930915 <taifu.gc@alibaba-inc.com> 37.0-2
- Remove nano-default-editor requirement in runtime-install.tmpl
- Enable dbus_daemon service

* Thu Apr 7 2022 gcdota930915 <taifu.gc@alibaba-inc.com> 37.0-1
- Fork from upstream community version 37.0 
